@@ -88,7 +88,7 @@ def run_server():
     currentPipelineFolder = os.path.abspath(os.getcwd())
     currentParentFolder = os.path.join(currentPipelineFolder,"..")
     os.environ["PYTHONPATH"] = currentPipelineFolder
-    folder = currentPipelineFolder + '/server/server_run.py'
+    folder = currentPipelineFolder + '/server/main.py'
     subprocess.call('python ' + folder, shell=True)
 
 @cli.command()
@@ -152,10 +152,11 @@ def create_project(project_name):
     create_pipeline_file(project_name, directories['main'], 'test_pipeline', False)
     # create_tester_file(project_name, directories['tester'], 'tester')
     # create_tester_file(project_name, directories['tester'], 'reporter')
-    create_tester_file(project_name, directories['server'], 'server_run', False)
-    create_tester_file(project_name, directories['server'], 'test_server_post', False)
-    create_tester_file(project_name, directories['server'], 'pool', False)
-    create_init_file(directories['server'] + '/__init__.py', 'from server.pool import InstancePool')
+    create_server_file(project_name, directories['server'], 'main', False)
+    create_server_file(project_name, directories['server'], 'test_server_post', False)
+    create_server_file(project_name, directories['server'], 'pool', False)
+    create_server_file(project_name, directories['server'], '__init__', False)
+    # create_init_file(directories['server'] + '/__init__.py', 'from server.main import app\nfrom server.pool import InstancePool')
     # create_tester_file(project_name, directories['trainer'], 'trainer')
     # create_pipeline_file(project_name, 'labelizer')
     # create_pipeline_file(project_name, 'pipeline')
@@ -163,7 +164,9 @@ def create_project(project_name):
     create_project_config_json()
     create_project_gitignore()
     create_server_config_json()
-    # copy_deploy_files(directories['main'])
+    copy_deploy_files(directories['main'])
+    create_dvc_init_file()
+    run_dvc_init()
     #
     # create_tester_file(project_name, 'dataset')
     # create_tester_file(project_name, 'reporter')
@@ -182,6 +185,10 @@ def create_pipeline_file(project_name, folder, pipelineType, createInitFile=True
     replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
 
 
+def create_server_file(project_name, folder, pipelineType, createInitFile=True):
+    data = read_template_file('tester/server/' + pipelineType)
+    replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
+
 def create_tester_file(project_name, folder, pipelineType, createInitFile=True):
     data = read_template_file('tester/' + pipelineType)
     replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
@@ -394,24 +401,45 @@ def create_server_config_json():
             f.write(data)
             f.close()
 
+def create_dvc_init_file():
+    with open(os.path.join(__location__, 'cli/tester/deploy_files/dvc_init.sh'), 'r') as file:
+        data = file.read()
+        data = data.replace('generatedDirectory', directories['main'])
+        new_file = directories['main'] + '/dvc_init.sh'
+        if not os.path.exists(new_file):
+            f = open(new_file, "w")
+            f.write(data)
+            f.close()
+
+def run_dvc_init():
+    if not os.path.isdir(directories['main'] + '/.dvc'):
+        os.chdir(directories['main'])
+        subprocess.call('dvc_init.sh', shell=True)
+
 def copy_deploy_files(main_dir):
     currentPipelineFolder = os.path.basename(os.getcwd())
-    dir = os.path.join(__location__, main_dir, 'cli/tester/deploy_files/')
+    dir = os.path.join(__location__, 'cli/tester/deploy_files/')
     listOfFiles = list()
     for (dirpath, dirname, filenames) in os.walk(dir):
         dirpath = dirpath.replace(dir, '')
         listOfFiles += [os.path.join(dirpath, file) for file in filenames]
         for file_path in listOfFiles:
-            with open(os.path.join(dir, file_path), 'r') as file:
-                data = file.read()
-                data = data.replace('{name-your-service}', currentPipelineFolder)
-                data = data.replace('{name-your-artifacts}', currentPipelineFolder)
-                if not os.path.exists('deploy'):
-                    os.makedirs('deploy')
-                if not os.path.exists(file_path):
-                    f = open(file_path, "w")
-                    f.write(data)
-                    f.close()
+            with open(os.path.join(dir, file_path), 'r', encoding="utf8") as file:
+                try:
+                    data = file.read()
+                    data = data.replace('{name-your-service}', currentPipelineFolder)
+                    data = data.replace('{name-your-artifacts}', currentPipelineFolder)
+                    dirToCreate = ''
+                    if main_dir:
+                        dirToCreate = main_dir + '/'
+                    if not os.path.exists(dirToCreate + 'deploy'):
+                        os.makedirs(dirToCreate + 'deploy')
+                    if not os.path.exists(dirToCreate + file_path):
+                        f = open(dirToCreate + file_path, "w")
+                        f.write(data)
+                        f.close()
+                except Exception as ex:
+                    pass
     # for item in os.listdir(dir):
     #     s = os.path.join(dir, item)
     #     d = os.path.join(main_dir, item)
